<template>
  <div>
    <el-dialog :title="dialogTitle" :visible.sync="dialogFormVisible" @close="closeDialog" :destroy-on-close="true" :append-to-body="true" :close-on-click-modal="false">
      <el-form :model="dictDataForm" :rules="dictDataRules" ref="dictDataForm" size="small">
        <el-form-item label="字典标签" :label-width="formLabelWidth" prop="dictLabel">
          <el-input v-model="dictDataForm.dictLabel" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item label="字典数值" :label-width="formLabelWidth" prop="dictValue">
          <el-input v-model="dictDataForm.dictValue" autocomplete="off"></el-input>
        </el-form-item>
        <el-form-item label="是否默认值" :label-width="formLabelWidth" prop="isDefault">
          <el-radio-group v-model="dictDataForm.isDefault">
            <el-radio label="0">是</el-radio>
            <el-radio label="1">否</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="状态" :label-width="formLabelWidth" prop="dictStatus">
          <el-radio-group v-model="dictDataForm.dictStatus">
            <el-radio label="0">正常</el-radio>
            <el-radio label="1">禁用</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="排序" :label-width="formLabelWidth" prop="dictSort">
          <el-input v-model="dictDataForm.dictSort" autocomplete="off"></el-input>
        </el-form-item>

      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="closeDialog" size="small">取 消</el-button>
        <el-button type="primary" @click="addOrEditDictData" size="small">确 定</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {Message} from "element-ui";
import {addDictData, editDictData, getDictDataByType} from "@/api/dict-data";

export default {
  name: "RoleDialog",
  data() {
    return {
      dictTypeId: this.$route.params.id,
      formLabelWidth: '120px',
      dictDataRules: {
        dictLabel: [
          { required: true, message: '请输入字典标签', trigger: 'blur' }
        ],
        dictValue: [
          { required: true, message: '请输入字典数值', trigger: 'blur' }
        ],
        isDefault: [
          { required: true, message: '请选择是否默认值', trigger: 'blur' }
        ],
        dictStatus: [
          { required: true, message: '请选择字典状态', trigger: 'change' }
        ],
      }
    }
  },
  computed: {
    dialogFormVisible: {
      get() {
        return this.$store.state.dictData.dialogFormVisible;
      },
      set(value) {
        this.$store.state.dictData.dialogFormVisible = value;
      }
    },
    dialogTitle() {
      return this.$store.state.dictData.dialogTitle;
    },
    dictDataForm: {
      get() {
        return this.$store.state.dictData.dictDataForm;
      },
      set(value) {
        this.$store.state.dictData.dictDataForm = value;
      }
    }
  },
  methods: {
    refreshData() {
      var params = {
        "current": this.$store.state.dictData.currentPage,
        "size": this.$store.state.dictData.pageSize,
        "dictTypeId": this.$store.state.dictData.dictDataForm.dictTypeId
      };
      // 刷新
      getDictDataByType(params).then((res) => {
        this.$store.state.dictData.tableData = res.data.data;
        this.$store.state.dictData.total = res.data.total;
        this.clearForm();
      })
    },
    clearForm() {
      Object.keys(this.dictDataForm).forEach((key) => {
        this.dictDataForm[key] = null;
      })
    },
    closeDialog() {
      this.$store.state.dictData.dialogFormVisible = false;
      this.clearForm();
    },
    addOrEditDictData() {
      this.$refs["dictDataForm"].validate((valid) => {
        if (valid) {
          if (this.dialogTitle === "添加字典类型") {
            addDictData(this.dictDataForm).then((res) => {
              Message.success(res.data.msg);
              this.dialogFormVisible = false;
              this.refreshData();
            })
          } else {
            editDictData(this.dictDataForm).then((res) => {
              this.dialogFormVisible = false;
              Message.success(res.data.msg);
              this.refreshData();
            })
          }
        } else {
          console.log('error submit!!');
          return false;
        }
      });
    }
  }
}
</script>

<style scoped>

</style>
